#!/usr/bin/env python3

import requests
import json


def resultado(jogo="megasena"):
    # Make the HTTP request
    response = requests.get('https://loteriascaixa-api.herokuapp.com/api/{}/latest'.format(jogo))

    # Parse the JSON response
    data = json.loads(response.text)

    # Extract the 'dezenas' array and join its elements with a comma
    result = ','.join(map(str, data['dezenas']))
    return result

def resultado_mega():
    return resultado()

def resultado_quina():
    return resultado(quina)



from .jogo import Jogo

class Quina(Jogo):
    def __init__(self, numeros_sorteados):
        super().__init__(80, numeros_sorteados)
        self.quantidade_numeros = 5

    def verifica_tipo_premio(self, acertos=0):
        if acertos == 2:
            print("---------------------")
            print("ACERTAMO UM DUQUE!!!")
            print("---------------------")
        elif acertos == 3:
            print("---------------------")
            print("ACERTAMO UM TERNO!!!")
            print("---------------------")
        elif acertos == 4:
            print("--------------------")
            print("ACERTAMO A QUADRA!!!")
            print("--------------------")
        elif acertos == 5:
            print("----------------------------")
            print("GANHAMOOOOOO CARALHOOOOOW!!!")
            print("----------------------------")
        else:
            pass



import csv
import random

class Jogo:
    def __init__(self, range_max, numeros_sorteados):
        self.range_max = range_max
        self.numeros_sorteados = numeros_sorteados

    def gerar_jogo(self):
        numeros = random.sample(range(1, self.range_max + 1), self.quantidade_numeros)
        numeros.sort()
        return numeros

    def gerar_jogos(self, qtde_jogos):
        jogos = []

        for _ in range(qtde_jogos):
            jogos.append(self.gerar_jogo())

        return jogos

    def verificar_premio(self, jogos):
        for i, jogo in enumerate(jogos, start=1):
            acertos = set(jogo).intersection(self.numeros_sorteados)
            print(f"Jogo {i}: {', '.join(map(str, jogo))} - Acertos: {len(acertos)}")
            self.verifica_tipo_premio(len(acertos))

    def carregar_jogos(self, arquivo):
        jogos = []
        with open(arquivo, 'r') as csvfile:
            leitor = csv.reader(csvfile)
            for linha in leitor:
                jogo = [int(numero) for numero in linha]
                jogos.append(jogo)
        return jogos

    def exportar_para_csv(self, jogos, path):
        with open(path, 'w', newline='') as csvfile:
            writer = csv.writer(csvfile)
            for jogo in jogos:
                writer.writerow(jogo)



import unittest
from src.lotodice.jogo import Jogo
from src.lotodice.mega import MegaSena
from src.lotodice.quina import Quina

class TestJogo(unittest.TestCase):

    def test_gerar_jogo(self):
        jogo = Jogo(60, [])
        jogo_gerado = jogo.gerar_jogo()
        self.assertEqual(len(jogo_gerado), 6)

    def test_verificar_premio(self):
        jogo = Jogo(60, [4, 11, 46, 48, 52])
        jogos = [[4, 11, 46, 48, 52, 53], [1, 2, 3, 4, 5, 6]]
        resultado_esperado = ["GANHAMOOOOOO CARALHOOOOOW!!!", ""]
        self.assertEqual(jogo.verificar_premio(jogos), resultado_esperado)

    def test_carregar_jogos(self):
        jogo = Jogo(60, [])
        jogos = jogo.carregar_jogos("jogos/jogos-dezembro-23.csv")
        self.assertEqual(len(jogos), 10)


class TestMegaSena(unittest.TestCase):

    def test_verifica_tipo_premio(self):
        mega = MegaSena([])
        self.assertEqual(mega.verifica_tipo_premio(6), "GANHAMOOOOOO CARALHOOOOOW!!!")


class TestQuina(unittest.TestCase):

    def test_verifica_tipo_premio(self):
        quina = Quina([])
        self.assertEqual(quina.verifica_tipo_premio(5), "GANHAMOOOOOO CARALHOOOOOW!!!")


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python3
import csv
from selenium import webdriver
from selenium.webdriver.common.by import By
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
from selenium.common.exceptions import WebDriverException


class LotteryAutomator:
    """Automates the process of selecting lottery numbers on the Caixa lottery website."""

    URL_TERMS_OF_USE = "https://www.loteriasonline.caixa.gov.br/silce-web/#/termos-de-uso"
    URL_MEGA_SENA = "https://www.loteriasonline.caixa.gov.br/silce-web/#/mega-sena"
    URL_QUINA = "https://www.loteriasonline.caixa.gov.br/silce-web/#/quina"

    def __init__(self, driver):
        self.driver = driver

    def navigate_and_accept_terms(self):
        """Navigates to the terms of use and accepts them."""
        self.driver.get(self.URL_TERMS_OF_USE)
        accept_button = WebDriverWait(self.driver, 10).until(
            EC.element_to_be_clickable((By.ID, "botaosim"))
        )
        accept_button.click()
        WebDriverWait(self.driver, 10).until(
            EC.url_to_be("https://www.loteriasonline.caixa.gov.br/silce-web/#/home")
        )

    def create_lottery_tickets(self, url, ticket_numbers):
        """Creates lottery tickets for either Mega Sena or Quina based on the provided URL and numbers."""
        for numbers in ticket_numbers:
            self.driver.get(url)
            WebDriverWait(self.driver, 10).until(
                EC.visibility_of_all_elements_located((By.CSS_SELECTOR, "ul.escolhe-numero li a.ng-binding"))
            )
            for number in numbers:
                number_element = WebDriverWait(self.driver, 10).until(
                    EC.element_to_be_clickable((By.XPATH, f"//a[text()='{number:02d}']"))
                )
                number_element.click()
            add_to_cart_button = WebDriverWait(self.driver, 10).until(
                EC.element_to_be_clickable((By.ID, "colocarnocarrinho"))
            )
            add_to_cart_button.click()

    def load_games_from_file(self, filepath):
        """Loads game numbers from a CSV file."""
        games = []
        with open(filepath, 'r') as csvfile:
            reader = csv.reader(csvfile)
            for row in reader:
                game = [int(number) for number in row]
                games.append(game)
        return games

    def run(self, mega_path, quina_path):
        """Runs the entire automation process for both Mega Sena and Quina lotteries."""
        self.navigate_and_accept_terms()
        mega_games = self.load_games_from_file(mega_path)
        quina_games = self.load_games_from_file(quina_path)
        self.create_lottery_tickets(self.URL_MEGA_SENA, mega_games)
        self.create_lottery_tickets(self.URL_QUINA, quina_games)

        while self.driver.window_handles:
            pass

def browser(mega_path, quina_path):
    options = webdriver.ChromeOptions()
    options.add_argument("--start-maximized")
    with webdriver.Chrome(options=options) as driver:
        automator = LotteryAutomator(driver)
        try:
            automator.run(mega_path, quina_path)
        except WebDriverException as e:
            print(f"An error occurred: {e}")
        finally:
            driver.quit()



from .jogo import Jogo

class MegaSena(Jogo):
    def __init__(self, numeros_sorteados):
        super().__init__(60, numeros_sorteados)
        self.quantidade_numeros = 6

    def verifica_tipo_premio(self, acertos=0):
        if acertos == 4:
            print("--------------------")
            print("ACERTAMO A QUADRA!!!")
            print("--------------------")
        elif acertos == 5:
            print("-------------------")
            print("ACERTAMO A QUINA!!!")
            print("-------------------")
        elif acertos == 6:
            print("----------------------------")
            print("GANHAMOOOOOO CARALHOOOOOW!!!")
            print("----------------------------")
        else:
            pass



#!/usr/bin/env python3
import argparse
from .jogo import Jogo
from .mega import MegaSena
from .quina import Quina
from .browser import *

def main():
    parser = argparse.ArgumentParser(description="Jogos da Mega Sena ou Quina")
    parser.add_argument("-t", "--tipo", choices=["mega", "quina"], help="Tipo de jogo (mega ou quina)")
    parser.add_argument("-q", "--quantidade", type=int, help="Quantidade de jogos a serem gerados")
    group = parser.add_mutually_exclusive_group()
    group.add_argument("-e", "--export", metavar="caminho_para_arquivo.csv", help="Exporta os jogos para um arquivo CSV")
    group.add_argument("-c", "--check", nargs=2, metavar=("arquivo.csv", "numeros_sorteados"), help="Verifica se os jogos contidos no arquivo CSV ganharam")
    group.add_argument("-b", "--browser", nargs=2, metavar=("mega.csv", "quina.csv"), help="Faz os jogos no site da Loterias Caixa")

    args = parser.parse_args()

    if args.check:
        arquivo, numeros_sorteados = args.check
        numeros_sorteados = list(map(int, numeros_sorteados.split(',')))
        jogo = MegaSena(numeros_sorteados) if args.tipo == 'mega' else Quina(numeros_sorteados)
        jogos = jogo.carregar_jogos(arquivo)
        print(f"Números sorteados: {', '.join(map(str, numeros_sorteados))}")
        jogo.verificar_premio(jogos)
    elif args.browser:
        mega, quina = args.browser
        browser(mega, quina)
    elif args.quantidade and args.tipo:
        jogo = MegaSena([]) if args.tipo == 'mega' else Quina([])
        resultados = jogo.gerar_jogos(args.quantidade)
        if args.export:
            jogo.exportar_para_csv(resultados, args.export)
            print(f"Jogos exportados para {args.export}")
        else:
            for i, jogo in enumerate(resultados, start=1):
                print(f"Jogo {i}: {', '.join(map(str, jogo))}")
    else:
        parser.print_help()


if __name__ == '__main__':
    main()
